@@ -1,15 +1,16 @@
-# NOTE: Do not require this file directly. Require 'gir_ffi' instead.
-#
+require 'gir_ffi/core'
 
 GirFFI.setup :GLib
 
 require 'ffi-glib/array'
 require 'ffi-glib/byte_array'
 require 'ffi-glib/bytes'
+require 'ffi-glib/destroy_notify'
 require 'ffi-glib/error'
 require 'ffi-glib/hash_table'
 require 'ffi-glib/iconv'
 require 'ffi-glib/list'
+require 'ffi-glib/main_loop'
 require 'ffi-glib/ptr_array'
 require 'ffi-glib/s_list'
 require 'ffi-glib/strv'
@@ -48,5 +49,6 @@ module GLib
     attach_function :g_ptr_array_foreach, [:pointer, Func, :pointer], :pointer
 
     attach_function :g_iconv_open, [:pointer, :pointer], :pointer
+    attach_function :g_variant_ref_sink, [:pointer], :pointer
   end
 end
