@@ -2,7 +2,7 @@ module GLib
   # Common methods for GLib::Array and GLib::PtrArray
   module ArrayMethods
     # Re-implementation of the g_array_index and g_ptr_array_index macros
-    def index idx
+    def index(idx)
       if idx >= length || idx < 0
         raise IndexError, "Index #{idx} outside of bounds 0..#{length - 1}"
       end
