@@ -6,24 +6,26 @@ module GLib
     include Enumerable
     attr_reader :element_type
 
-    def self.included base
+    def self.included(base)
       # Override default field accessors.
       replace_method base, :next, :tail
       replace_method base, :data, :head
 
-      class << base; self end.send :remove_method, :new
-      base.extend ListClassMethods
-
       base.extend ContainerClassMethods
     end
 
-    def self.replace_method base, old, new
+    def self.replace_method(base, old, new)
       base.class_eval do
         remove_method old
         alias_method old, new
       end
     end
 
+    def initialize(type)
+      store_pointer(FFI::Pointer.new(0))
+      @element_type = type
+    end
+
     def each
       reset_iterator
       while (elem = next_element)
@@ -39,12 +41,12 @@ module GLib
       GirFFI::ArgHelper.cast_from_pointer(element_type, @struct[:data])
     end
 
-    def reset_typespec typespec
+    def reset_typespec(typespec)
       @element_type = typespec
       self
     end
 
-    def == other
+    def ==(other)
       to_a == other.to_a
     end
 
@@ -55,25 +57,14 @@ module GLib
     end
 
     def next_element
-      return if !@current
+      return unless @current
       element = @current.head
       @current = @current.tail
       element
     end
 
-    def element_ptr_for data
+    def element_ptr_for(data)
       GirFFI::InPointer.from(element_type, data)
     end
-
-    # Common class methods for List and SList
-    module ListClassMethods
-      def new type
-        _real_new.tap do |it|
-          struct = self::Struct.new(FFI::Pointer.new(0))
-          it.instance_variable_set :@struct, struct
-          it.instance_variable_set :@element_type, type
-        end
-      end
-    end
   end
 end
