@@ -6,7 +6,7 @@ module GObjectIntrospection
       Lib.g_enum_info_get_n_values @gobj
     end
 
-    def value index
+    def value(index)
       IValueInfo.wrap(Lib.g_enum_info_get_value @gobj, index)
     end
     ##
@@ -16,7 +16,7 @@ module GObjectIntrospection
       Lib.g_enum_info_get_n_methods @gobj
     end
 
-    def get_method index
+    def get_method(index)
       IFunctionInfo.wrap(Lib.g_enum_info_get_method @gobj, index)
     end
 
