@@ -6,7 +6,7 @@ module GObjectIntrospection
       Lib.g_interface_info_get_n_prerequisites @gobj
     end
 
-    def prerequisite index
+    def prerequisite(index)
       IBaseInfo.wrap(Lib.g_interface_info_get_prerequisite @gobj, index)
     end
 
@@ -17,33 +17,34 @@ module GObjectIntrospection
       Lib.g_interface_info_get_n_properties @gobj
     end
 
-    def property index
+    def property(index)
       IPropertyInfo.wrap(Lib.g_interface_info_get_property @gobj, index)
     end
 
     ##
     build_array_method :properties, :property
+    build_finder_method :find_property, :n_properties
 
     def get_n_methods
       Lib.g_interface_info_get_n_methods @gobj
     end
 
-    def get_method index
+    def get_method(index)
       IFunctionInfo.wrap(Lib.g_interface_info_get_method @gobj, index)
     end
 
     ##
     build_array_method :get_methods
 
-    def find_method name
-      IFunctionInfo.wrap(Lib.g_interface_info_find_method @gobj, name)
+    def find_method(name)
+      IFunctionInfo.wrap(Lib.g_interface_info_find_method @gobj, name.to_s)
     end
 
     def n_signals
       Lib.g_interface_info_get_n_signals @gobj
     end
 
-    def signal index
+    def signal(index)
       ISignalInfo.wrap(Lib.g_interface_info_get_signal @gobj, index)
     end
 
@@ -55,14 +56,14 @@ module GObjectIntrospection
       Lib.g_interface_info_get_n_vfuncs @gobj
     end
 
-    def vfunc index
+    def vfunc(index)
       IVFuncInfo.wrap(Lib.g_interface_info_get_vfunc @gobj, index)
     end
 
     ##
     build_array_method :vfuncs
 
-    def find_vfunc name
+    def find_vfunc(name)
       IVFuncInfo.wrap(Lib.g_interface_info_find_vfunc @gobj, name)
     end
 
@@ -70,7 +71,7 @@ module GObjectIntrospection
       Lib.g_interface_info_get_n_constants @gobj
     end
 
-    def constant index
+    def constant(index)
       IConstantInfo.wrap(Lib.g_interface_info_get_constant @gobj, index)
     end
 
@@ -80,6 +81,5 @@ module GObjectIntrospection
     def iface_struct
       IStructInfo.wrap(Lib.g_interface_info_get_iface_struct @gobj)
     end
-
   end
 end
