@@ -26,7 +26,7 @@ module GObjectIntrospection
       Lib.g_object_info_get_n_interfaces @gobj
     end
 
-    def interface index
+    def interface(index)
       IInterfaceInfo.wrap(Lib.g_object_info_get_interface @gobj, index)
     end
 
@@ -37,7 +37,7 @@ module GObjectIntrospection
       Lib.g_object_info_get_n_fields @gobj
     end
 
-    def field index
+    def field(index)
       IFieldInfo.wrap(Lib.g_object_info_get_field @gobj, index)
     end
 
@@ -48,7 +48,7 @@ module GObjectIntrospection
       Lib.g_object_info_get_n_properties @gobj
     end
 
-    def property index
+    def property(index)
       IPropertyInfo.wrap(Lib.g_object_info_get_property @gobj, index)
     end
 
@@ -60,22 +60,22 @@ module GObjectIntrospection
       Lib.g_object_info_get_n_methods @gobj
     end
 
-    def get_method index
+    def get_method(index)
       IFunctionInfo.wrap(Lib.g_object_info_get_method @gobj, index)
     end
 
     ##
     build_array_method :get_methods
 
-    def find_method name
-      IFunctionInfo.wrap(Lib.g_object_info_find_method @gobj, name)
+    def find_method(name)
+      IFunctionInfo.wrap(Lib.g_object_info_find_method @gobj, name.to_s)
     end
 
     def n_signals
       Lib.g_object_info_get_n_signals @gobj
     end
 
-    def signal index
+    def signal(index)
       ISignalInfo.wrap(Lib.g_object_info_get_signal @gobj, index)
     end
 
@@ -87,12 +87,12 @@ module GObjectIntrospection
       Lib.g_object_info_get_n_vfuncs @gobj
     end
 
-    def vfunc index
+    def vfunc(index)
       IVFuncInfo.wrap(Lib.g_object_info_get_vfunc @gobj, index)
     end
 
-    def find_vfunc name
-      IVFuncInfo.wrap(Lib.g_object_info_find_vfunc @gobj, name)
+    def find_vfunc(name)
+      IVFuncInfo.wrap(Lib.g_object_info_find_vfunc @gobj, name.to_s)
     end
     ##
     build_array_method :vfuncs
@@ -101,7 +101,7 @@ module GObjectIntrospection
       Lib.g_object_info_get_n_constants @gobj
     end
 
-    def constant index
+    def constant(index)
       IConstantInfo.wrap(Lib.g_object_info_get_constant @gobj, index)
     end
     ##
