@@ -6,7 +6,7 @@ module GObjectIntrospection
       Lib.g_struct_info_get_n_fields @gobj
     end
 
-    def field index
+    def field(index)
       IFieldInfo.wrap(Lib.g_struct_info_get_field @gobj, index)
     end
 
@@ -18,13 +18,13 @@ module GObjectIntrospection
       Lib.g_struct_info_get_n_methods @gobj
     end
 
-    def get_method index
+    def get_method(index)
       IFunctionInfo.wrap(Lib.g_struct_info_get_method @gobj, index)
     end
 
     ##
     build_array_method :get_methods
-    # There is a function g_object_info_find_method but it causes a core dump.
+    # There is a function g_struct_info_find_method but it causes a core dump.
     build_finder_method :find_method, :get_n_methods, :get_method
 
     def size
