@@ -10,7 +10,7 @@ module GObjectIntrospection
       Lib.g_type_info_get_tag @gobj
     end
 
-    def param_type index
+    def param_type(index)
       ITypeInfo.wrap(Lib.g_type_info_get_param_type @gobj, index)
     end
 
@@ -36,7 +36,7 @@ module GObjectIntrospection
     end
 
     def name
-      raise "Should not call this for ITypeInfo"
+      raise 'Should not call this for ITypeInfo'
     end
   end
 end
