@@ -8,7 +8,7 @@ module GLib
 
     POINTER_SIZE = FFI.type_size(:pointer)
 
-    def initialize ptr
+    def initialize(ptr)
       @ptr = ptr
     end
 
@@ -17,20 +17,20 @@ module GLib
     end
 
     def each
-      reset_iterator or return
+      return if @ptr.null?
+      reset_iterator
       while (ptr = next_ptr)
         yield ptr.read_string
       end
     end
 
-    def self.wrap ptr
+    def self.wrap(ptr)
       new ptr
     end
 
     private
 
     def reset_iterator
-      return if @ptr.null?
       @offset = 0
     end
 
