@@ -14,20 +14,14 @@ module GirFFI
       end
 
       def value_spec
-        info.values.map {|vinfo|
+        info.values.map do|vinfo|
           val = GirFFI::ArgHelper.cast_uint32_to_int32(vinfo.value)
           [vinfo.name.to_sym, val]
-        }.flatten
-      end
-
-      def instantiate_class
-        @enum = optionally_define_constant klass, :Enum do
-          lib.enum(enum_sym, value_spec)
-        end
-        setup_class unless already_set_up
+        end.flatten
       end
 
       def setup_class
+        setup_ffi_type
         klass.extend superclass
         setup_constants
         stub_methods
@@ -38,6 +32,12 @@ module GirFFI
         @klass ||= get_or_define_module namespace_module, @classname
       end
 
+      def setup_ffi_type
+        optionally_define_constant klass, :Enum do
+          lib.enum(enum_sym, value_spec)
+        end
+      end
+
       def setup_inspect
         klass.instance_eval <<-EOS
           def self.inspect
@@ -47,11 +47,11 @@ module GirFFI
       end
 
       def already_set_up
-        klass.respond_to? :get_gtype
+        klass.respond_to? :gtype
       end
 
       def superclass
-        @superclass ||= EnumBase
+        EnumBase
       end
     end
   end
