@@ -1,6 +1,7 @@
 require 'gir_ffi/builder_helper'
 require 'gir_ffi/module_base'
 require 'gir_ffi/builders/function_builder'
+
 require 'indentation'
 
 module GirFFI
@@ -10,7 +11,7 @@ module GirFFI
     class ModuleBuilder
       include BuilderHelper
 
-      def initialize namespace, version = nil
+      def initialize(namespace, version = nil)
         @namespace = namespace
         @version = version
         # FIXME: Pass safe namespace as an argument
@@ -21,23 +22,30 @@ module GirFFI
         modul
       end
 
-      def setup_method method
+      def setup_method(method)
         go = function_introspection_data method.to_s
         return false unless go
 
         Builder.attach_ffi_function lib, go
-        modul.class_eval FunctionBuilder.new(go).generate
+        modul.class_eval FunctionBuilder.new(go).method_definition
 
         true
       end
 
-      def build_namespaced_class classname
-        info = gir.find_by_name @namespace, classname.to_s
+      def build_namespaced_class(classname)
+        info = find_namespaced_class_info(classname)
+        Builder.build_class info
+      end
+
+      def find_namespaced_class_info(classname)
+        name = classname.to_s
+        info = gir.find_by_name(@namespace, name) ||
+          gir.find_by_name(@namespace, name.sub(/^./, &:downcase))
         unless info
           raise NameError,
-            "Class #{classname} not found in namespace #{@namespace}"
+                "Class #{classname} not found in namespace #{@namespace}"
         end
-        Builder.build_class info
+        info
       end
 
       private
@@ -54,10 +62,10 @@ module GirFFI
 
       def build_dependencies
         deps = gir.dependencies @namespace
-        deps.each {|dep|
+        deps.each do|dep|
           name, version = dep.split '-'
           Builder.build_module name, version
-        }
+        end
       end
 
       def instantiate_module
@@ -75,6 +83,7 @@ module GirFFI
 
       def setup_lib_for_ffi
         lib.extend FFI::Library
+        lib.extend FFI::BitMasks
         lib.ffi_lib_flags :global, :lazy
         if shared_library_specification
           lib.ffi_lib(*shared_library_specification.split(/,/))
@@ -93,7 +102,7 @@ module GirFFI
         @lib ||= get_or_define_module modul, :Lib
       end
 
-      def function_introspection_data function
+      def function_introspection_data(function)
         info = gir.find_by_name @namespace, function.to_s
         return unless info
         info.info_type == :function ? info : nil
