@@ -20,12 +20,12 @@ module GirFFI
         end
       end
 
-      def find_signal signal_name
+      def find_signal(signal_name)
         seek_in_ancestor_infos { |info| info.find_signal signal_name } or
           raise "Signal #{signal_name} not found"
       end
 
-      def find_property property_name
+      def find_property(property_name)
         seek_in_ancestor_infos { |info| info.find_property property_name } or
           raise "Property #{property_name} not found"
       end
@@ -38,6 +38,13 @@ module GirFFI
         @ancestor_infos ||= [info] + info.interfaces + parent_ancestor_infos
       end
 
+      protected
+
+      def object_class_struct_info
+        @object_class_struct_info ||=
+          info.class_struct || parent_builder.object_class_struct_info
+      end
+
       private
 
       def setup_class
@@ -51,6 +58,7 @@ module GirFFI
         end
         setup_vfunc_invokers
         setup_interfaces
+        provide_initializer
       end
 
       # FIXME: Private method only used in subclass
@@ -99,7 +107,7 @@ module GirFFI
         end
       end
 
-      def define_vfunc_invoker vfunc_name, invoker_name
+      def define_vfunc_invoker(vfunc_name, invoker_name)
         return if vfunc_name == invoker_name
         klass.class_eval "
           def #{vfunc_name} *args, &block
@@ -108,6 +116,16 @@ module GirFFI
         "
       end
 
+      def provide_initializer
+        return if info.find_method 'new'
+
+        klass.class_eval "
+          def initialize(properties = {})
+            base_initialize(properties)
+          end
+        "
+      end
+
       def setup_interfaces
         interfaces.each do |iface|
           klass.send :include, iface
@@ -120,10 +138,6 @@ module GirFFI
         end
       end
 
-      def object_class_struct_info
-        @object_class_struct_info ||= info.class_struct
-      end
-
       def seek_in_ancestor_infos
         ancestor_infos.each do |info|
           item = yield info
