@@ -26,7 +26,9 @@ module GirFFI
         arg_infos << ErrorArgumentInfo.new if info.throws?
 
         receiver_info = ReceiverArgumentInfo.new receiver_type_info
-        return_value_info = ReturnValueInfo.new info.return_type
+        return_value_info = ReturnValueInfo.new(info.return_type,
+                                                info.caller_owns,
+                                                info.skip_return?)
 
         MappingMethodBuilder.for_vfunc(receiver_info,
                                        arg_infos,
@@ -47,7 +49,7 @@ module GirFFI
 
       def argument_ffi_types
         @argument_ffi_types ||= info.argument_ffi_types.
-          unshift(receiver_type_info.to_callback_ffitype)
+          unshift(receiver_type_info.to_callback_ffi_type)
       end
 
       def return_ffi_type
