@@ -4,7 +4,7 @@ module GirFFI
   module Builders
     # Implements the creation of classes representing types with layout,
     # i.e., :union, :struct, :object.
-    # Note: This module depends on methods in RegisteredTypeBuilder.
+    # NOTE: This module depends on methods in RegisteredTypeBuilder.
     module WithLayout
       def layout_specification
         spec = base_layout_specification
@@ -23,15 +23,15 @@ module GirFFI
       end
 
       def dummy_layout_specification
-        if parent
-          [:parent, superclass.const_get(:Struct), 0]
+        if parent_info
+          [:parent, superclass::Struct, 0]
         else
           [:dummy, :char, 0]
         end
       end
 
       def base_layout_specification
-        fields.map { |finfo| finfo.layout_specification }.flatten(1)
+        fields.map(&:layout_specification).flatten(1)
       end
 
       def setup_field_accessors
@@ -40,10 +40,6 @@ module GirFFI
         end
       end
 
-      def instantiate_class
-        setup_class unless already_set_up
-      end
-
       def klass
         @klass ||= get_or_define_class namespace_module, @classname, superclass
       end
