@@ -12,50 +12,56 @@ module GirFFI
       FFI::Type::POINTER
     end
 
-    def self.from_native value, _context
+    def self.from_native(value, _context)
       return nil if !value || value.null?
       FFI::Function.new(gir_ffi_builder.return_ffi_type,
                         gir_ffi_builder.argument_ffi_types, value)
     end
 
-    def self.to_native value, _context
+    def self.to_native(value, _context)
       case value
       when CallbackBase
         value.to_native
       when FFI::Function
         value
-      else
-        nil
       end
     end
 
-    def self.wrap ptr
+    def self.wrap(ptr)
       from_native ptr, nil
     end
 
-    CALLBACKS = []
+    CALLBACKS = {}
 
-    def self.store_callback prc
-      CALLBACKS << prc
+    def self.store_callback(prc)
+      CALLBACKS[prc.object_id] = prc
+    end
+
+    def self.drop_callback(key)
+      CALLBACKS.delete key
     end
 
     # Create Callback from a Proc. Makes sure arguments are properly wrapped,
     # and the callback is stored to prevent garbage collection.
-    def self.from prc
-      wrap_in_callback_args_mapper(prc).tap do |cb|
+    def self.from(prc)
+      wrap_proc(prc).tap do |cb|
         store_callback cb
       end
     end
 
-    def self.wrap_in_callback_args_mapper prc
+    def self.wrap_proc(prc)
       return unless prc
 
       new do |*args|
-        call_with_argument_mapping(prc, *args)
+        begin
+          call_with_argument_mapping(prc, *args)
+        rescue => e
+          GLib::MainLoop.handle_exception e
+        end
       end
     end
 
-    def self.to_ffitype
+    def self.to_ffi_type
       self
     end
 
@@ -67,12 +73,12 @@ module GirFFI
                      end
     end
 
-    def self.copy_value_to_pointer value, pointer
+    def self.copy_value_to_pointer(value, pointer)
       pointer.put_pointer 0, to_native(value, nil)
     end
 
-    def self.get_value_from_pointer pointer
-      from_native pointer.get_pointer(0), nil
+    def self.get_value_from_pointer(pointer, offset)
+      from_native pointer.get_pointer(offset), nil
     end
   end
 end
