@@ -16,13 +16,17 @@ module GirFFI
     end
 
     def name
-      "_error"
+      '_error'
     end
 
     def closure
       -1
     end
 
+    def destroy
+      -1
+    end
+
     def caller_allocates?
       true
     end
