@@ -4,21 +4,25 @@ module GirFFI
   module InfoExt
     # Extensions for GObjectIntrospection::IRegisteredTypeInfo needed by GirFFI
     module IRegisteredTypeInfo
-      def to_ffitype
-        to_type.to_ffitype
+      def to_ffi_type
+        to_type.to_ffi_type
       end
 
       def to_type
         Builder.build_class self
       end
 
-      def find_instance_method method
+      def find_instance_method(method)
         info = find_method method
         return info if info && info.method?
       end
+
+      def find_method(_method)
+        raise 'Must be overridden in subclass'
+      end
     end
   end
 end
 
 GObjectIntrospection::IRegisteredTypeInfo.send :include,
-  GirFFI::InfoExt::IRegisteredTypeInfo
+                                               GirFFI::InfoExt::IRegisteredTypeInfo
