@@ -19,9 +19,9 @@ module GirFFI
         }
       end
 
-      def g_type
+      def gtype
         if tag == :interface
-          return interface.g_type
+          return interface.gtype
         elsif (type = ITypeInfo.flattened_tag_to_gtype_map[flattened_tag])
           return type
         else
@@ -30,7 +30,7 @@ module GirFFI
       end
 
       def make_g_value
-        GObject::Value.for_g_type g_type
+        GObject::Value.for_gtype gtype
       end
 
       def element_type
@@ -39,8 +39,6 @@ module GirFFI
           enumerable_element_type
         when :ghash
           dictionary_element_type
-        else
-          nil
         end
       end
 
@@ -99,21 +97,20 @@ module GirFFI
         end
       end
 
-      def to_ffitype
+      def to_ffi_type
         return :pointer if pointer?
 
         case tag
         when :interface
-          interface.to_ffitype
+          interface.to_ffi_type
         when :array
-          [subtype_ffitype(0), array_fixed_size]
+          [subtype_ffi_type(0), array_fixed_size]
         else
           TypeMap.map_basic_type tag
         end
       end
 
-      # TODO: Use either ffitype or ffi_type everywhere
-      def to_callback_ffitype
+      def to_callback_ffi_type
         return :pointer if pointer?
 
         case tag
@@ -166,6 +163,10 @@ module GirFFI
         [:array, :c, :ghash, :struct, :strv].include?(flattened_tag)
       end
 
+      def needs_ruby_to_c_conversion_for_closures?
+        [:array].include?(flattened_tag)
+      end
+
       def extra_conversion_arguments
         case flattened_tag
         when :utf8, :void
@@ -179,9 +180,15 @@ module GirFFI
         end
       end
 
+      GOBJECT_VALUE_NAME = 'GObject::Value'
+
+      def gvalue?
+        argument_class_name == GOBJECT_VALUE_NAME
+      end
+
       private
 
-      def subtype_tag_or_class index
+      def subtype_tag_or_class(index)
         param_type(index).tag_or_class
       end
 
@@ -193,8 +200,8 @@ module GirFFI
         subtype_tag_or_class 0
       end
 
-      def subtype_ffitype index
-        subtype = param_type(index).to_ffitype
+      def subtype_ffi_type(index)
+        subtype = param_type(index).to_ffi_type
         if subtype == :pointer
           # NOTE: Don't use pointer directly to appease JRuby.
           :"uint#{FFI.type_size(:pointer) * 8}"
