@@ -1,10 +1,14 @@
+require 'gir_ffi/info_ext/full_type_name'
+
 module GirFFI
   # Represents a type not found in the GIR, conforming, as needed, to the
   # interface of GObjectIntrospection::IObjectInfo.
   class UnintrospectableTypeInfo
     attr_reader :g_type
 
-    def initialize gtype, gir = GObjectIntrospection::IRepository.default, gobject = GObject
+    def initialize(gtype,
+                   gir = GObjectIntrospection::IRepository.default,
+                   gobject = GObject)
       @g_type = gtype
       @gir = gir
       @gobject = gobject
@@ -39,5 +43,14 @@ module GirFFI
     def fields
       []
     end
+
+    def find_signal(_any)
+      nil
+    end
+
+    # TODO: Create custom class that includes the interfaces instead
+    def class_struct
+      parent.class_struct
+    end
   end
 end
