@@ -1,16 +1,15 @@
 require 'gir_ffi_test_helper'
 
 describe GLib::IConv do
-  describe ".open" do
-    it "creates a new instance of GLib::Iconv" do
-      instance = GLib::IConv.open("ascii", "utf-8")
+  let(:instance) { GLib::IConv.open('ascii', 'utf-8') }
+
+  describe '.open' do
+    it 'creates a new instance of GLib::Iconv' do
       instance.must_be_instance_of GLib::IConv
     end
   end
 
-  let(:instance) { GLib::IConv.open("ascii", "utf-8") }
-
-  describe "#setup_and_call" do
+  describe '#setup_and_call' do
     it "works for the method called ''" do
       instance.setup_and_call :'', [nil, nil, nil, nil]
     end
