@@ -1,16 +1,16 @@
 require 'gir_ffi_test_helper'
 
 describe GirFFI::Builders::EnumBuilder do
-  describe "creating Regress::TestEnum" do
+  describe 'creating Regress::TestEnum' do
     before do
       save_module :Regress
     end
 
-    it "makes the created type know its proper name" do
+    it 'makes the created type know its proper name' do
       info = get_introspection_data 'Regress', 'TestEnum'
       builder = GirFFI::Builders::EnumBuilder.new info
       enum = builder.build_class
-      enum.inspect.must_equal "Regress::TestEnum"
+      enum.inspect.must_equal 'Regress::TestEnum'
     end
 
     after do
