@@ -1,12 +1,12 @@
 require 'gir_ffi_test_helper'
 
 describe GirFFI::Builders::UnintrospectableBuilder do
-  describe "building the GLocalFile type" do
+  describe 'building the GLocalFile type' do
     before do
       # Ensure existence of GLocalFile type
       GirFFI.setup :Gio
       unless Gio::Lib.respond_to? :g_file_new_for_path
-        Gio.setup_method "file_new_for_path"
+        Gio.setup_method 'file_new_for_path'
       end
       ptr = GirFFI::InPointer.from :utf8, '/'
       Gio::Lib.g_file_new_for_path(ptr)
@@ -17,35 +17,46 @@ describe GirFFI::Builders::UnintrospectableBuilder do
       @klass = @bldr.build_class
     end
 
-    it "builds a class" do
+    it 'builds a class' do
       assert_instance_of Class, @klass
     end
 
-    it "builds a class derived from GObject::Object" do
+    it 'builds a class derived from GObject::Object' do
       assert_includes @klass.ancestors, GObject::Object
     end
 
-    it "builds a class derived from Gio::File" do
+    it 'builds a class derived from Gio::File' do
       assert_includes @klass.ancestors, Gio::File
     end
 
-    it "returns the same class when built again" do
+    it 'returns the same class when built again' do
       other_bldr = GirFFI::Builders::UnintrospectableBuilder.new(@info)
       other_klass = other_bldr.build_class
 
       assert_equal @klass, other_klass
     end
 
-    describe "its #find_signal method" do
+    describe 'its #find_signal method' do
       it "raises correct error for a signal that doesn't exist" do
         msg = nil
         begin
-          @bldr.find_signal "foo"
+          @bldr.find_signal 'foo'
         rescue RuntimeError => e
           msg = e.message
         end
         assert_match(/^Signal/, msg)
       end
+
+      it 'finds signals in ancestor classes' do
+        signal = @bldr.find_signal 'notify'
+        signal.name.must_equal 'notify'
+      end
+    end
+
+    describe '#object_class_struct' do
+      it 'returns the parent class struct' do
+        @bldr.object_class_struct.must_equal GObject::ObjectClass
+      end
     end
   end
 end
