@@ -1,6 +1,6 @@
 module Minitest
   class StatsReporter < AbstractReporter
-    def initialize _options
+    def initialize(_options)
       @results = []
     end
 
@@ -8,19 +8,19 @@ module Minitest
       @current_time = Time.now
     end
 
-    def record result
+    def record(result)
       @results << result
     end
 
     def report
       slowest = @results.sort_by(&:time).reverse.first(10)
       slowest.each do |result|
-        puts "%10.4f %s" % [result.time, result.location]
+        puts format('%10.4f %s', result.time, result.location)
       end
     end
   end
 
   def self.plugin_stats_init(options)
-    self.reporter << StatsReporter.new(options)
+    reporter << StatsReporter.new(options)
   end
 end
